<?php
/**
 * Adding support for WooCommerce Plugin
 */

if ( ! class_exists( 'WooCommerce' ) ) {
    // Bail early if WooCommerce Plugin is not installed
    return;
}

if ( ! function_exists( 'adventurous_woocommerce_setup' ) ) :
    /**
     * Sets up support for various WooCommerce features.
     */
    function adventurous_woocommerce_setup() {
        add_theme_support( 'woocommerce' );

        $options = adventurous_get_options();

        if ( ! $options['disable_product_gallery_zoom'] ) {
            add_theme_support('wc-product-gallery-zoom');
        }

        if ( ! $options['disable_product_gallery_lightbox'] ) {
            add_theme_support('wc-product-gallery-lightbox');
        }

        if ( ! $options['disable_product_gallery_slider'] ) {
            add_theme_support('wc-product-gallery-slider');
        }
    }
endif; //adventurous_woocommerce_setup
add_action( 'after_setup_theme', 'adventurous_woocommerce_setup' );


/**
 * uses remove_action to remove the WooCommerce Wrapper and add_action to add Simple Catch Wrapper
 *
 */
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);

if ( ! function_exists( 'adventurous_woocommerce_start' ) ) :
function adventurous_woocommerce_start() {
	echo '<div id="primary" class="content-area"><div id="content" class="site-content woocommerce" role="main">';
}
endif; //adventurous_woocommerce_start
add_action('woocommerce_before_main_content', 'adventurous_woocommerce_start', 15);

if ( ! function_exists( 'adventurous_woocommerce_end' ) ) :
function adventurous_woocommerce_end() {
	echo '</div></div>';
}
endif; //adventurous_woocommerce_end
add_action('woocommerce_after_main_content', 'adventurous_woocommerce_end', 15);


function adventurous_woocommerce_options( $wp_customize ) {
    $defaults = adventurous_get_defaults();

    // WooCommerce Options
    $wp_customize->add_section( 'adventurous_woocommerce_options', array(
        'title'       => esc_html__( 'WooCommerce Options', 'adventurous-pro' ),
        'priority'    => 220,
        'panel'       => 'adventurous_theme_options',
        'description' => esc_html__( 'Since these options are added via theme support, you will need to save and refresh the customizer to view the full effect.', 'adventurous-pro' ),
    ) );

    $wp_customize->add_setting( 'adventurous_options[disable_product_gallery_zoom]', array(
        'default'           => $defaults['disable_product_gallery_zoom'],
        'sanitize_callback' => 'adventurous_sanitize_checkbox',
        'type'              => 'option',
    ) );

    $wp_customize->add_control( 'adventurous_options[disable_product_gallery_zoom]', array(
        'label'     => esc_html__( 'Check to disable Product Gallery Zoom', 'adventurous-pro' ),
        'section'   => 'adventurous_woocommerce_options',
        'type'      => 'checkbox',
    ) );

    $wp_customize->add_setting( 'adventurous_options[disable_product_gallery_lightbox]', array(
        'default'           => $defaults['disable_product_gallery_lightbox'],
        'sanitize_callback' => 'adventurous_sanitize_checkbox',
        'type'              => 'option',
    ) );

    $wp_customize->add_control( 'adventurous_options[disable_product_gallery_lightbox]', array(
        'label'     => esc_html__( 'Check to disable Product Gallery Lightbox', 'adventurous-pro' ),
        'section'   => 'adventurous_woocommerce_options',
        'type'      => 'checkbox',
    ) );

    $wp_customize->add_setting( 'adventurous_options[disable_product_gallery_slider]', array(
        'default'           => $defaults['disable_product_gallery_slider'],
        'sanitize_callback' => 'adventurous_sanitize_checkbox',
        'type'              => 'option',
    ) );

    $wp_customize->add_control( 'adventurous_options[disable_product_gallery_slider]', array(
        'label'     => esc_html__( 'Check to disable Product Gallery Slider', 'adventurous-pro' ),
        'section'   => 'adventurous_woocommerce_options',
        'type'      => 'checkbox',
    ) );
}
add_action( 'customize_register', 'adventurous_woocommerce_options' );